@@ -10,7 +10,7 @@ fn files_setup(file_size: usize, num_files: usize, ext: &str) -> Result<TempDir,
     let mut bytes = Vec::with_capacity(file_size);
     (0..file_size).for_each(|_| bytes.push(rng.gen()));
 
-    let temp_dir = tempdir::TempDir::new("test_files")?;
+    let temp_dir = TempDir::new("test_files")?;
 
     let _ = (0..num_files).into_par_iter().for_each(|i| {
         fs::write(
@@ -24,6 +24,13 @@ fn files_setup(file_size: usize, num_files: usize, ext: &str) -> Result<TempDir,
 
 #[tokio::main]
 async fn main() -> CommandResult {
+    let sol_keypair_path = env::var("SOL_KEYPAIR_PATH");
+    if sol_keypair_path.is_err() {
+        println!("Example requires SOL_KEYPAIR_PATH environment variable to be set.");
+        return Ok(());
+    };
+    let sol_keypair_path = sol_keypair_path.unwrap();
+
     let ext = "bin";
     let temp_dir = files_setup(10_000_000, 20, ext)?;
     let log_dir = temp_dir.path().join("status");
@@ -31,8 +38,6 @@ async fn main() -> CommandResult {
 
     let arweave = Arweave::default();
 
-    let sol_keypair_path = env::var("SOL_KEYPAIR_PATH").unwrap();
-
     let glob_str = format!("{}/*.{}", temp_dir.path().display().to_string(), ext);
     let log_dir_str = log_dir.display().to_string();
 
